import logging


class ln():

    def __init__(self, origin=None, toscreen=True, tofile=None) -> None:
        logging.getLogger().handlers = []
        self.logger = logging.getLogger(origin)  # configure `root` logger when no arguments passed

        self.logger.setLevel(logging.INFO)
        # formatter = logging.Formatter('%(asctime)s[%(filename)s:%(lineno)d]: %(message)s', datefmt='[%m-%d %H:%M:%S]')
        # formatter = logging.Formatter('%(message)s', datefmt='[%m-%d %H:%M:%S]')
        formatter = logging.Formatter("[%(asctime)s %(process)d] %(message)s")

        if toscreen:
            ch = logging.StreamHandler()
            ch.setLevel(logging.INFO)
            ch.setFormatter(formatter)
            self.logger.addHandler(ch)

        if tofile is not None:
            fh = logging.FileHandler(tofile)
            fh.setLevel(logging.INFO)
            fh.setFormatter(formatter)
            self.logger.addHandler(fh)


    def get_logger(self):
        return self.logger

    def debug(self, output):
        self.logger.debug(output)

    def info(self, output):
        self.logger.info(output)

    def warning(self, output):
        self.logger.warning(output)

    def error(self, output):
        self.logger.error(output)


if __name__ == '__main__':
    log = ln(__name__, toscreen=True, tofile='trainer.log').get_logger()
    log.info('no')



#%%
from matplotlib import pyplot as plt
import numpy as np
import matplotlib.font_manager as fm
from matplotlib.pyplot import MultipleLocator
import os

plt.style.use('ggplot')
root = os.path.dirname(os.path.abspath(__file__))
FONT_PATH = os.path.join(root, 'arial.ttf')

def get_font(path=FONT_PATH, font_size=12, font_color='black'):
    font = fm.FontProperties(fname=path)
    font.set_size(font_size)
    # font.set_color(font_color)
    return font


def ax_default_style(ax, font_size=12, font_color='black', show_grid=False, show_legend=False, ratio=1.0, **kwargs):
    '''
    render the axes to a defined style
    '''
    _font = get_font(font_size=font_size, font_color=font_color)
    ax.set_facecolor('white')
    bwith = 1
    ax.spines['top'].set_color('black')
    ax.spines['right'].set_color('black')
    ax.spines['bottom'].set_color('black')
    ax.spines['left'].set_color('black')
    ax.spines['bottom'].set_linewidth(bwith)
    ax.spines['left'].set_linewidth(bwith)
    ax.spines['top'].set_linewidth(bwith)
    ax.spines['right'].set_linewidth(bwith)

    if show_legend:
        legend = ax.legend(prop=_font, labelcolor=font_color)
        frame = legend.get_frame()
        frame.set_alpha(0.8)
        frame.set_facecolor('white')

    if show_grid:
        ax.grid('on', color='#e6e6e6')
    else:
        ax.grid(False)

    for label in ax.get_xticklabels():
        label.set_fontproperties(_font)
        label.set_color(font_color)
    for label in ax.get_yticklabels():
        label.set_fontproperties(_font)
        label.set_color(font_color)
    ax.xaxis.get_label().set_fontproperties(_font)
    ax.yaxis.get_label().set_fontproperties(_font)
    ax.xaxis.get_label().set_color(font_color)
    ax.yaxis.get_label().set_color(font_color)

    # ax.set(aspect=1.0 / ax.get_data_ratio() * ratio)



def ax_lims(ax, lims=[0, 0, 0, 0], interval_xticks=None, interval_yticks=None):
    '''
    adjust x and y limits
    '''
    if lims[0] + lims[1] != 0:
        ax.set_xlim([lims[0], lims[1]])
    if lims[2] + lims[3] != 0:
        ax.set_ylim([lims[2], lims[3]])
    if interval_xticks is not None:
        ax.xaxis.set_major_locator(MultipleLocator(interval_xticks))
    if interval_yticks is not None:
        ax.yaxis.set_major_locator(MultipleLocator(interval_yticks))


if __name__ == '__main__':
    fig, axs = plt.subplots(1, 1, figsize=(5, 5), squeeze=False)
    ax = axs[0][0]
    ax.plot(np.arange(100), np.random.rand(100), marker='o', label='test')
    ax.set_xlabel('harmonic_mean_std')
    ax.set_ylabel('recall@1')
    ax_lims(ax, interval_xticks=20, interval_yticks=1)
    ax_default_style(ax, font_size=20)



# from pynvml import *

# def schedule_device():
#     ''' output id of the graphic card with most free memory
#     '''
#     nvmlInit()
#     deviceCount = nvmlDeviceGetCount()
#     frees = []
#     for i in range(deviceCount):
#         handle = nvmlDeviceGetHandleByIndex(i)
#         # print("GPU", i, ":", nvmlDeviceGetName(handle))
#         info = nvmlDeviceGetMemoryInfo(handle)
#         frees.append(info.free / 1e9)
#     nvmlShutdown()
#     # print(frees)
#     id = frees.index(max(frees))
#     # print(id)
#     return id

import os
def schedule_device():
    info_per_card = os.popen('"nvidia-smi" --query-gpu=memory.total,memory.used --format=csv,nounits,noheader').read().split('\n')         # ['40536, 9948', '40536, 18191', '40536, 14492', '']

    card_memory_used = []
    for i in range(len(info_per_card)):
        if info_per_card[i] == '':
            continue
        else:
            total, used = int(info_per_card[i].split(',')[0]), int(info_per_card[i].split(',')[1])
            # print('Total GPU mem:', total, 'used:', used)
            card_memory_used.append(used)
    # print(card_memory_used.index(min(card_memory_used)))
    return int(card_memory_used.index(min(card_memory_used)))



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(name="matin",
                 version="0.1",
                 author="anonymous",
                 author_email="anonymous@anonymous.com",
                 description="A handy formatter for matplotlib",
                #  long_description=long_description,
                 long_description_content_type="text/markdown",
                 url="http://www.example.com/~cschultz/bvote/",
                 project_urls={
                     "Bug Tracker": "http://bitbucket.org/tarek/distribute/issues/",
                 },
                 classifiers=[
                     "Programming Language :: Python :: 3",
                     "License :: OSI Approved :: MIT License",
                     "Operating System :: OS Independent",
                 ],
                 package_dir={"": "src"},
                 packages=setuptools.find_packages(where="src"),
                 python_requires=">=3.6",
                 install_requires=['matplotlib'],
                 package_data={"": ["*.ttf"]})
